#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
from http.client import NOT_MODIFIED

# import interfaces
from pyams_file.interfaces import IFile, IImage
from zope.dublincore.interfaces import IZopeDublinCore

# import packages
from pyramid.response import Response
from pyramid.view import view_config


@view_config(context=IFile)
def FileView(request):
    """Default file view"""
    context = request.context

    # check for last modification date
    modified = IZopeDublinCore(context).modified
    if_modified_since = request.if_modified_since
    if if_modified_since and (int(modified.timestamp()) <= int(if_modified_since.timestamp())):
        return Response(status=NOT_MODIFIED)

    headers = {'Content-Disposition': 'attachment; filename="{0}"'.format(context.filename)}
    response = Response(content_type=context.content_type.decode('utf-8'),
                        headers=headers)
    response.last_modified = modified
    response.body_file = context.get_blob(mode='c')
    return response


@view_config(context=IImage)
def ImageView(request):
    """Default image view"""
    context = request.context

    # check for last modification date
    modified = IZopeDublinCore(context).modified
    if_modified_since = request.if_modified_since
    if if_modified_since and (int(modified.timestamp()) <= int(if_modified_since.timestamp())):
        return Response(status=NOT_MODIFIED)

    response = Response(content_type=context.content_type.decode('utf-8'))
    response.last_modified = modified
    response.body_file = context.get_blob(mode='c')
    return response
